//
//  GalleryViewController.m
//  PhotoSearch
//
//  Created by Roanne Mendoza on 12/12/12.
//  Copyright (c) 2012 Roanne Mendoza. All rights reserved.
//

#import "GalleryViewController.h"
#import "Request.h"

@interface GalleryViewController () {
    NSMutableArray* searchResultInstagram;
    NSMutableArray* searchResultFlickr;
    NSMutableString* instagramMaxId;
    IBOutlet UICollectionView* gallery;
    IBOutlet UITextField* searchField;
    IBOutlet UIView* loader;
    BOOL isFlickr;
}

@end

@implementation GalleryViewController

#pragma mark - View LifeCycle
- (id)initWithCoder:(NSCoder *)aDecoder {
    if (self = [super initWithCoder:aDecoder]) {
        searchResultFlickr = [[NSMutableArray alloc] init];
        searchResultInstagram = [[NSMutableArray alloc] init];
        instagramMaxId = [[NSMutableString alloc] initWithString:@"0"];
        isFlickr = YES;
    }
    
    return self;
}

- (void)viewWillAppear:(BOOL)animated {
    [super viewWillAppear:animated];
    [gallery reloadData];
}

- (void)viewDidLoad {
    [gallery registerClass:[UICollectionViewCell class] forCellWithReuseIdentifier:@"photo"];
}

#pragma mark - Actions
- (IBAction)search:(id)sender {
    if ([sender tag] == 1) {
        isFlickr = YES;
        [searchResultFlickr removeAllObjects];
    } else {
        isFlickr = NO;
        [searchResultInstagram removeAllObjects];
        [self requestData];
    }
}

#pragma mark - Data Request
- (void)requestData {
    [self showLoader];
    if (isReachable()) {
        if (isFlickr) {
            
        } else {
            NSDictionary* data = getInstagramFeed([searchField text], instagramMaxId);
            if ([[[data objectForKey:@"meta"] objectForKey:@"code"] intValue] == 200) {
                [searchResultInstagram addObjectsFromArray:[InstagramPhoto buildInstagramFeedFromJSON:[data objectForKey:kTagInstagramData]]];
                [gallery reloadData];
                [self hideLoader];
            } else {
                //alert
                [self hideLoader];
            }
        }
    } else {
        //alert
        [self hideLoader];
    }
}

#pragma mark - Others
- (void)showLoader {
    [loader setHidden:NO];
    [self.view setUserInteractionEnabled:NO];
}

- (void)hideLoader {
    [self.view setUserInteractionEnabled:YES];
    [loader setHidden:YES];
}

#pragma mark - UICollectionViewDataSource
- (NSInteger)numberOfSectionsInCollectionView:(UICollectionView *)collectionView {
    return [searchResultInstagram count];
}

- (NSInteger)collectionView:(UICollectionView *)collectionView numberOfItemsInSection:(NSInteger)section {
    return [searchResultInstagram count];
}

- (UICollectionViewCell *)collectionView:(UICollectionView *)collectionView cellForItemAtIndexPath:(NSIndexPath *)indexPath {
    NSString* identifier = isFlickr ? @"flickr" : @"instagram";
    UICollectionViewCell* cell = [collectionView dequeueReusableCellWithReuseIdentifier:identifier forIndexPath:indexPath];
    [cell setBackgroundColor:[UIColor lightGrayColor]];
    
    return cell;
}

#pragma mark - UICollectionViewDelegate
- (void)collectionView:(UICollectionView *)collectionView didSelectItemAtIndexPath:(NSIndexPath *)indexPath {
    
}

#pragma mark - UICollectionViewDelegateFlowLayout
- (CGSize)collectionView:(UICollectionView *)collectionView layout:(UICollectionViewLayout*)collectionViewLayout sizeForItemAtIndexPath:(NSIndexPath *)indexPath {
    CGSize retval;
    if (isFlickr) {
        retval = /*photo.thumbnail.size.width > 0 ? photo.thumbnail.size : */CGSizeMake(100, 100);
    } else {
        InstagramPhoto* photo = (InstagramPhoto*)[searchResultInstagram objectAtIndex:[indexPath row]];
        retval = CGSizeMake(photo.thumbDimension, photo.thumbDimension);
    }
//    NSString *searchTerm = self.searches[indexPath.section]; FlickrPhoto *photo =
//    self.searchResults[searchTerm][indexPath.row];
    // 2
    retval.height += 35; retval.width += 35;
    return retval;
}

// 3
- (UIEdgeInsets)collectionView:(UICollectionView *)collectionView layout:(UICollectionViewLayout*)collectionViewLayout insetForSectionAtIndex:(NSInteger)section {
    return UIEdgeInsetsMake(50, 20, 50, 20);
}

@end
